## Anonfiles.com direct link generator

Generate direct link for downloading file from anonfiles.com

## Requirements

At least Python 3 and **beautifulsoup4**

## Usage

```
from anonfiles-directlink import direct_link

link = 'some anonfiles link'
download_link = direct_link(link)
print(direct_link)
```